/*
 * Generates the repetitive part of the gnuplot input
 * for generating the initial triangle vertices from SGT's
 * model.
 */

#include "common.h"
#include "mgraph.h"

int main(int argc, const char **argv) {
  static const int prec= DBL_DIG+2;
  int vi, k;
  
  if (argc!=10 || !strlen(argv[2]) || strlen(argv[2]) != strlen(argv[3]))
    { fputs("wrong # args or lengths\n",stderr); exit(8); }

  printf("%s%d%s%d%s%d%s%d%s%d\n",
	 argv[7], DIM, argv[8], N, argv[8], X, argv[8], Y, argv[8], D3);
  
  FOR_VERTEX(vi) {
    int x= vi & XMASK; /* distance along strip */
    int y= vi >> YSHIFT; /* distance across strip */
    double u= y * 1.0 / (Y-1); /* SGT's u runs 0..1 across the strip */

    /* SGT's v runs 0..pi along the strip, where the join is at 0==pi.
     * So that corresponds to 0..X (since 0==X in our scheme).
     * Vertices with odd y coordinate are halfway to the next x coordinate.
     */
    double v= (x*2 + (y&1)) * 1.0 / (X*2);

    if (!strchr(argv[9],'u'))
      v *= M_PI;
    
    K {
      if (k >= strlen(argv[2])) break;
      printf("%s%c%c%s%-*.*g%s%-*.*g%s%03x %2d %2d\n",
	     argv[1], argv[2][k], argv[3][k], argv[4],
	     prec+5,prec,u, argv[5], prec+5,prec,v,
	     argv[6], vi, x, y);
    }
  }
  flushoutput();
  return 0;
}
